.. _sec-config:

``eradiate._config``
====================

.. automodule:: eradiate._config

.. py:currentmodule:: eradiate._config


.. toctree::
   :hidden:

   generated/env_vars/env_vars.rst

.. button-ref:: generated/env_vars/env_vars
   :color: primary
   :expand:

   Environment variable list

Classes
-------

.. autoclass:: EradiateConfig
   :members:

.. autoclass:: ProgressLevel
   :members:
   :member-order: bysource

Attributes
----------

.. autodata:: config
   :annotation:
